Index: trunk/MagicSoft/Simulation/Detector/Camera/camera.h
===================================================================
--- trunk/MagicSoft/Simulation/Detector/Camera/camera.h	(revision 2334)
+++ trunk/MagicSoft/Simulation/Detector/Camera/camera.h	(revision 2335)
@@ -19,7 +19,7 @@
 //=
 //= $RCSfile: camera.h,v $
-//= $Revision: 1.17 $
+//= $Revision: 1.18 $
 //= $Author: blanch $ 
-//= $Date: 2003-07-17 18:03:03 $
+//= $Date: 2003-09-15 10:06:47 $
 //=
 //=//////////////////////////////////////////////////////////////////////
@@ -114,5 +114,5 @@
 #define RandomNumber  drand48()
 
-#define iMAXNUMPIX  595 // total maximum possible number of pixels in the camera
+#define iMAXNUMPIX  3500 // total maximum possible number of pixels in the camera
 
 #define iMAXNUMPHE 50000 // maximum total number of photoelectrons in one event
@@ -279,5 +279,5 @@
 int igen_pixel_coordinates(struct camera *cam);
 void read_pixels(struct camera *cam); 
-void read_QE(char fname[256]);
+void read_QE(char fname[256], int ict);
 void read_WC(void);
 void read_ascii( FILE *sp, // the input file
@@ -286,5 +286,5 @@
 int pixels_are_neig(int pix1, int pix2);
 int bpoint_is_in_pix(double dx, double dy, int ipixnum, 
-		      MGeomCamMagic *pcamgeom); 
+		      MGeomCam *pcamgeom); 
 float  dist_r_P(float a, float b, float c, 
                 float l, float m, float n,
@@ -293,5 +293,5 @@
 float lin_interpol(float x1, float y1, float x2, float y2, float x);
 int produce_phes( FILE *sp, // the input file
-		  class MGeomCamMagic *camgeom, // the camera layout
+		  class MGeomCam *camgeom, // the camera layout
 		  float minwl_nm, // the minimum accepted wavelength
 		  float maxwl_nm, // the maximum accepted wavelength
@@ -302,10 +302,12 @@
 		  int *incph,    // total number of cph read
 		  float *tmin_ns,   // minimum arrival time of all phes
-		  float *tmax_ns   // maximum arrival time of all phes
+		  float *tmax_ns,    // maximum arrival time of all phes
+		  int telescope      // Telescope that is being analised to get the right QE.
 		  ); 
 
 int produce_nsbrates( char *inname,
-		      MGeomCamMagic *camgeom,
-		      float nsbrate[][iNUMWAVEBANDS]
+		      MGeomCam *camgeom,
+		      float nsbrate[][iNUMWAVEBANDS],
+		      int ict
 		      );
 
@@ -336,4 +338,7 @@
 /*
  *$Log: not supported by cvs2svn $
+ *Revision 1.17  2003/07/17 18:03:03  blanch
+ *Header file for camera 1.57
+ *
  *Revision 1.15  2003/01/07 16:34:09  blanch
  *Header file for camera.cxx version 1.50.
